import 'dart:io';

import 'option.dart';
import 'terminal.dart';

// Properties outside the class. The variable is private using _ (using const to avoid to have multiple instance of Terminal)
final Terminal _terminal = const Terminal();

class Prompter {
  // Single question with y or no as answers.
  bool askBinary(String question) {
    try {
      return _ask("$question (y/n):", []).contains('y');
    } catch (err) {
      stdout.writeln("an error occurred: $err");
      return false;
    }
  }

  // Show to the user question and answers and wait for a response.
  dynamic askMultiple(String question, List<Option> options) {
    final input = _ask(question, options);
    // Parse to int and return
    try {
      return options[int.parse(input)].value;
    } catch (err) {
      // in case of error ask again
      return askMultiple(question, options);
    }
  }

  // Internal useful and common method
  String _ask(String question, List<Option> options) {
    _terminal.clearScreen();
    _terminal.printPrompt(question);
    _terminal.printOptions(options);
    return _terminal.collectInput();
  }
}
